@@ -6,7 +6,7 @@ import os, sys, requests, ast, json, pathlib, glob, platform, subprocess, random
 import traceback as _traceback_
 
 # inc imports.
-from fil3s import Files, Formats
+from fil3s import *
 
 # functions.
 def __get_operating_system__():
@@ -68,6 +68,9 @@ BASE = __get_source_path__(SOURCE_PATH)
 OS = __get_operating_system__()
 #__check_alias__(alias=ALIAS, executable=f"{SOURCE_PATH}/")
 
+# version.
+version = Files.load(f"{SOURCE_PATH}/.version")
+
 # universal variables.
 USER = OWNER = os.environ.get("USER")
 GROUP = "root"
